@@ -95,7 +95,9 @@ def patch_django_asgi_handler_impl(cls):
             return await old_app(self, scope, receive, send)
 
         middleware = SentryAsgiMiddleware(
-            old_app.__get__(self, cls), unsafe_context_data=True
+            old_app.__get__(self, cls),
+            unsafe_context_data=True,
+            span_origin=DjangoIntegration.origin,
         )._run_asgi3
 
         return await middleware(scope, receive, send)
@@ -132,8 +134,8 @@ def patch_get_response_async(cls, _before_get_response):
 
 def patch_channels_asgi_handler_impl(cls):
     # type: (Any) -> None
-
     import channels  # type: ignore
+
     from sentry_sdk.integrations.django import DjangoIntegration
 
     if channels.__version__ < "3.0.0":
@@ -145,7 +147,9 @@ def patch_channels_asgi_handler_impl(cls):
                 return await old_app(self, receive, send)
 
             middleware = SentryAsgiMiddleware(
-                lambda _scope: old_app.__get__(self, cls), unsafe_context_data=True
+                lambda _scope: old_app.__get__(self, cls),
+                unsafe_context_data=True,
+                span_origin=DjangoIntegration.origin,
             )
 
             return await middleware(self.scope)(receive, send)
@@ -160,6 +164,8 @@ def patch_channels_asgi_handler_impl(cls):
 
 def wrap_async_view(callback):
     # type: (Any) -> Any
+    from sentry_sdk.integrations.django import DjangoIntegration
+
     @functools.wraps(callback)
     async def sentry_wrapped_callback(request, *args, **kwargs):
         # type: (Any, *Any, **Any) -> Any
@@ -168,7 +174,9 @@ def wrap_async_view(callback):
             sentry_scope.profile.update_active_thread_id()
 
         with sentry_sdk.start_span(
-            op=OP.VIEW_RENDER, description=request.resolver_match.view_name
+            op=OP.VIEW_RENDER,
+            description=request.resolver_match.view_name,
+            origin=DjangoIntegration.origin,
         ):
             return await callback(request, *args, **kwargs)
 
